@@ -24,8 +24,8 @@
  * CSV̲
  *
  * $RCSfile: result.php,v $
- * $Revision: 1.1.1.1 $
- * $Date: 2010/04/22 01:52:47 $
+ * $Revision: 1.2 $
+ * $Date: 2010/06/24 08:46:27 $
  **********************************************************/
 
 include_once("../../initial");
@@ -694,7 +694,7 @@ function print_csv_result()
     }
 
     /* ֥եɹ */
-    $ret = read_tab_conf();
+    $ret = read_tab_conf(ADMINTABCONF);
     if ($ret === FALSE) {
         print($err_msg);
         $pg->display_footer();
