@@ -24,8 +24,8 @@
  * ѥ桼
  *
  * $RCSfile: index.php,v $
- * $Revision: 1.2 $
- * $Date: 2010/06/10 05:26:46 $
+ * $Revision: 1.3 $
+ * $Date: 2010/06/23 09:04:46 $
  **********************************************************/
 
 include_once("../../initial");
@@ -149,6 +149,7 @@ function print_title($sum, $filter)
     global $page;
     global $filter_disp;
     global $url_data;
+    global $plugindata;
 
     /* ڡֹ0ϤޤäƤ */
     $all_page = (int) ceil(($sum / $web_conf[$url_data["script"]]["lineperpage"]));
@@ -181,6 +182,14 @@ function print_title($sum, $filter)
         $next = "<a href=\"#\" onClick=\"allSubmit('index.php', '$tmp', '')\">ڡ</a>";
     }
 
+    /*  */
+    $colum = COLUM_DEF;
+
+    $count = count($plugindata);
+    if ($count > 0) {
+        $colum += $count;
+    }
+
     print <<<EOD
 
 <script type="text/javascript">
@@ -203,7 +212,7 @@ function allSubmit(url, page, dn) {
 <table class="table">
     <tr>
         <td class="search_sum">[ $sum ]</td>
-        <td colspan="5" class="search_tmp" style="border:1px solid #000000;">
+        <td colspan="$colum" class="search_tmp" style="border:1px solid #000000;">
           <table class="guide" align="right">
             <tr>
               <td class="search_prev">$pre</td>
@@ -218,6 +227,17 @@ function allSubmit(url, page, dn) {
         <td class="search_trans">᡼žɥ쥹</td>
         <td class="search_quota">᡼</td>
         <td class="search_ref"></td>
+EOD;
+    /* ץ饰ʬɲ */
+    if ($count > 0) {
+        for ($i = 0; $i < $count; $i++) {
+            print<<<EOD
+        <td class="search_ref"></td>
+EOD;
+        }
+    }
+
+    print<<<EOD
     </tr>
 
 EOD;
@@ -244,6 +264,7 @@ function print_result()
     global $page;
     global $limit_adm;
     global $url_data;
+    global $plugindata;
 
     /* ̤ɽ°̾ǥ */
     if (isset($ldap_result)) {
@@ -319,13 +340,28 @@ function print_result()
             }
         }
 
-    print <<<EOD
+        /* ץ饰Խ̤ؤΥɽ */
+        $html_plugin = "";
+        $count = count($plugindata);
+        if ($count > 0) {
+            for ($j = 0; $j < $count; $j++) {
+                $p_name = $plugindata[$j]["name"];
+                $file = $plugindata[$j]["file"];
+                $image = $plugindata[$j]["image"];
+                $html_plugin .=<<<EOD
+        <td class="value_center"><input type="button" class="plugin_btn" style="background:url(images/${image});" onClick="allSubmit('$file', '$page', '$userdn')" title="${p_name}Խ"></td>
+EOD;
+            }
+        }
+
+        print <<<EOD
     <tr>
         <td class="value">{$name}</td>
         <td class="value_alias">{$alias}</td>
         <td class="value_trans">{$trans}</td>
         <td class="value_right">{$quota}</td>
-        <td class="value_center"><a href="#" onClick="allSubmit('mod.php', '$page', '$userdn')">Խ</a></td>
+        <td class="value_center"><input type="button" class="list_mod_btn" onClick="allSubmit('mod.php', '$page', '$userdn')" title="桼Խ"></td>
+$html_plugin
     </tr>
 
 EOD;
@@ -490,6 +526,9 @@ if ($ret === FALSE) {
     exit (1);
 }
 
+/* ץ饰ǡå */
+set_plugindata();
+
 /***********************************************************
  * main
  **********************************************************/
